@@ -28,6 +28,18 @@ false;
 // strings
 "hello!" && 'hi there!';
 "esc\"aped" && 'esc\'aped';
+`this is a multi-line template string,
+with a string ${variable} inlined and ${nesting `in ${here}`}.`;
+
+// template string
+
+`template string
+and it spans multiple lines
+with escapes \` \${this isn't highlighted}`
+
+html`tagged template ${interpolation
+
+across lines} and outside again ${and inside!}`
 
 // Capitalized identifiers are treated as types
 new String('foo');
@@ -39,19 +51,28 @@ arr[1] = 'foo';
 // hashes
 dog = {
   color: "brown",
-  "size": "large"
+  "size": "large",
+  delete: 123,
 };
 dog["color"]; // results in "brown"
 dog.color;    // also results in "brown"
+dog.delete;   // not a keyword
 
 // regular expressions
 /ab{3}c/;
-
 /ab{3}\/dc/; // with escaped terminator
 /ab{3}/gim; // with flags
 
-// not a regex below
+// regexes used in various contexts
+if (/[0-9]/.test('6')) alert('Digit');
+invoke(/[0-9]/, /abc/);
+invoke(/[0-9]/, on_res(/abc/));
+
+// not regexes below
 var foo = 2 / 2;
+var bar = 2 / 2 / 3;
+var zed = 2 / 2 / other_var;
+var frob = var1 / var2 / other_var;
 
 // function declarations
 var add = new Function('x', 'y', 'return x+y');
@@ -60,6 +81,24 @@ MyType.field = function(a, b) { return a + b; }
 function add2(x, y) {
     return x + y;
 }
+var f = function* (a, b) { yield* 123; }
+function* g(c) { yield c; }
 var
   foo = 1,
-  my_func = function() {}
+  my_func = function() {};
+
+// aync await
+async function () {
+  await Promise.resolve(true);
+}
+
+// modules
+import foo from './foo';
+export default 'a';
+
+// class
+class Foo extends Bar {
+  constructor () {
+    super();
+  }
+}
